@@ -21,7 +21,8 @@ class Context(LoadableDataclass):
     Attributes
     ----------
     author
-        A :class:`Member` object representing the invoking user.
+        A :class:`User` or  :class:`Member` object representing the invoking
+        user.
     id
         The unique ID (snowflake) of this interaction.
     type
@@ -42,8 +43,11 @@ class Context(LoadableDataclass):
         The name of the command that was invoked.
     command_id
         The unique ID (snowflake) of the command that was invoked.
+    users
+        :class:`User` objects for each user specified as an option.
     members
-        :class:`Member` objects for each user specified as an option.
+        :class:`Member` objects for each user specified as an option, if this
+        command was invoked in a guild.
     channels
         :class:`Channel` objects for each channel specified as an option.
     roles
@@ -51,7 +55,7 @@ class Context(LoadableDataclass):
     target
         The targeted :class:`User` or message.
     """
-    author: Member = None
+    author: Union[Member, User] = None
     id: str = None
     type: int = None
     token: str = None
@@ -89,7 +93,6 @@ class Context(LoadableDataclass):
         result = cls(
             app = app,
             discord = discord,
-            author = Member.from_dict(data.get("member", {})),
             id = data.get("id"),
             type = data.get("data", {}).get("type") or ApplicationCommandType.CHAT_INPUT,
             token = data.get("token"),
@@ -106,6 +109,7 @@ class Context(LoadableDataclass):
 
         result.data = data
 
+        result.parse_author(data)
         result.parse_custom_id()
         result.parse_resolved()
         result.parse_target()
@@ -118,6 +122,26 @@ class Context(LoadableDataclass):
         else:
             return self.frozen_auth_headers
 
+    def parse_author(self, data):
+        """
+        Parse the author (invoking user) of this interaction.
+
+        This will set :attr:`author` to a :class:`User` object if this
+        interaction occurred in a direct message, or a :class:`Member` object
+        if interaction occurred in a guild.
+
+        Parameters
+        ----------
+        data
+            The incoming interaction data.
+        """
+        if data.get("member"):
+            self.author = Member.from_dict(data["member"])
+        elif data.get("user"):
+            self.author = User.from_dict(data["user"])
+        else:
+            self.author = None
+
     def parse_custom_id(self):
         """
         Parse the custom ID of the incoming interaction data.
@@ -143,6 +167,10 @@ class Context(LoadableDataclass):
             member_info["user"] = self.resolved["users"][id]
             self.members[id] = Member.from_dict(member_info)
 
+        self.users = {id: User.from_dict(data)
+                      for id, data
+                      in self.resolved.get("users", {}).items()}
+
         self.channels = {id: Channel.from_dict(data)
                          for id, data
                          in self.resolved.get("channels", {}).items()}
@@ -207,10 +235,13 @@ class Context(LoadableDataclass):
                     kwargs.update(sub_kwargs)
 
                 elif option["type"] == CommandOptionType.USER:
-                    member_data = resolved["members"][option["value"]]
-                    member_data["user"] = resolved["users"][option["value"]]
+                    if "members" in resolved:
+                        member_data = resolved["members"][option["value"]]
+                        member_data["user"] = resolved["users"][option["value"]]
 
-                    kwargs[option["name"]] = Member.from_dict(member_data)
+                        kwargs[option["name"]] = Member.from_dict(member_data)
+                    else:
+                        kwargs[option["name"]] = User.from_dict(resolved["users"][option["value"]])
 
                 elif option["type"] == CommandOptionType.CHANNEL:
                     kwargs[option["name"]] = Channel.from_dict(
